import { get } from 'lodash-es';
import { Divider } from 'antd';
import * as React from 'react';
import { css } from '@emotion/css';
import { useInstalledExtensionsQuery, useGalleryQuery, useRemoveMutation, useInstallMutation } from 'common/lib/generated/generated.js';
import '../components/ExtensionView.js';
import { ExtensionsList } from '../components/ExtensionsList.js';
import { ExtensionSearchForm } from '../components/ExtensionSearchForm.js';

const Extensions = props => {
  const [ids, setIds] = React.useState([]);
  const [text, setText] = React.useState('');
  const [names, setNames] = React.useState([]);
  const [pageSize, setPageSize] = React.useState(20);
  const {
    data: installed,
    ...installedResult
  } = useInstalledExtensionsQuery();
  const {
    data: gallery,
    loading,
    error: galleryError,
    refetch
  } = useGalleryQuery({
    variables: {
      query: {
        ids,
        text,
        names,
        pageSize
      }
    }
  });
  const [removeExtension] = useRemoveMutation();
  const [installExtension] = useInstallMutation();
  const onInstall = mutate => extension => {
    mutate({
      variables: {
        vsix: extension.assets.download.uri
      }
    }).then(() => refetch());
  };
  const onRemove = mutate => id => {
    mutate({
      variables: {
        id
      }
    }).then(() => refetch());
  };
  const onSearch = searchText => {
    setText(searchText);
  };
  return React.createElement("div", {
    className: css(styles.root)
  }, React.createElement(ExtensionSearchForm, {
    onSearch: onSearch
  }), React.createElement(Divider, {
    style: {
      margin: '0 0 10px 0'
    },
    type: "horizontal"
  }), React.createElement(ExtensionsList, {
    loading: loading,
    mode: "gallery",
    onRemove: onRemove(removeExtension),
    onInstall: onInstall(installExtension),
    installed: get(installed, 'installed'),
    extensions: get(gallery, 'gallery.firstPage'),
    onSelect: id => {
      console.log('Selected Extension ID ', id);
    }
  }));
};
const styles = {
  root: {
    width: '100%',
    height: '100%',
    display: 'flex',
    overflowY: 'auto',
    flexDirection: 'column'
  }
};

export { Extensions };
//# sourceMappingURL=Extensions.js.map
