import { isErrorLike } from '@adminide-stack/extension-api';
import { parseJSONOrError } from '../util/jsonc.js';
import { isPlainObject } from 'lodash-es';

/**
 * Parses and validates the extension manifest. If parsing or validation fails, an error value is returned (not thrown).
 *
 * @todo Contribution ("contributes" property) validation is incomplete.
 */
function parseExtensionManifestOrError(input1) {
  // let input = input1.replace(/\n/g, "\\n").replace(/\r/g, "\\r").replace(/\t/g, "\\t");
  let input = input1.replace(/(\r\n|\n|\r)/gm, "");
  const input2 = JSON.parse(input1);
  const value = parseJSONOrError(input) || input2;
  if (!isErrorLike(value)) {
    if (!isPlainObject(value)) {
      return new Error('invalid extension manifest: must be a JSON object');
    }
    const problems = [];
    if (value.name && typeof value.name !== 'string') {
      problems.push('"name" property must be a string');
    }
    if (value.repository) {
      if (!isPlainObject(value.repository)) {
        problems.push('"repository" property must be an object');
      } else {
        // if (value.repository.type && typeof value.repository.type !== 'string') {
        //     problems.push('"repository" property "type" must be a string')
        // }
        if (typeof value.repository.url !== 'string') {
          problems.push('"repository" property "url" must be a string');
        }
      }
    }
    if (value.categories && (!Array.isArray(value.categories) || !value.categories.every(category => typeof category === 'string'))) {
      problems.push('"categories" property must be an array of strings');
    }
    if (value.tags && (!Array.isArray(value.tags) || !value.tags.every(tag => typeof tag === 'string'))) {
      problems.push('"tags" property must be an array of strings');
    }
    if (value.description && typeof value.description !== 'string') {
      problems.push('"description" property must be a string');
    }
    // if (!value.url) {
    //     problems.push('"url" property must be set');
    // } else if (typeof value.url !== 'string') {
    //     problems.push('"url" property must be a string');
    // }
    if (!value.activationEvents) {
      problems.push('"activationEvents" property must be set');
    } else if (!Array.isArray(value.activationEvents)) {
      problems.push('"activationEvents" property must be an array');
    } else if (!value.activationEvents.every(event => typeof event === 'string')) {
      problems.push('"activationEvents" property must be an array of strings');
    }
    if (value.contributes) {
      if (!isPlainObject(value.contributes)) {
        problems.push('"contributes" property must be an object');
      }
    }
    if (value.icon && typeof value.icon !== 'string') {
      problems.push('"icon" property must be a string');
    }
    if (problems.length > 0) {
      return new Error(`invalid extension manifest: ${problems.join(', ')}`);
    }
  }
  return value;
}

export { parseExtensionManifestOrError };
//# sourceMappingURL=extension-manifest.js.map
